@@ -1,8 +1,6 @@
 import logging
 import time
-# import pyperclip
 
-from selenium import webdriver
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.common.action_chains import ActionChains
 
@@ -11,10 +9,8 @@ from .srt_parser import open_srt, get_srt_portions
 
 
 class Translator:
-    def __init__(self):
-        logging.info("Opening browser")
-        self.driver = webdriver.Firefox()
-        self.driver.maximize_window()
+    def __init__(self, driver):
+        self.driver = driver
 
         logging.info("Going to DeepL")
         self.driver.get("https://www.deepl.com/translator")
@@ -54,10 +50,10 @@ class Translator:
             "lmt__language_select--target",
         ).click()
 
-        input_lang_button = Button(
+        Button(
             self.driver,
             "XPATH",
-            f"//button[@dl-test='translator-lang-option-{lang_to['lang'].lower()}-{lang_to['lang'].upper()}'] | //button[text()='{lang_to['description']}']",
+            f"//button[@dl-test='translator-lang-option-{lang_to['lang'].lower()}'] | //button[text()='{lang_to['description']}']",
         ).click()
 
     def translate(self, file_path, lang_from, lang_to, wrap_limit):
@@ -71,21 +67,15 @@ class Translator:
             text = "\n".join(text)
 
             logging.info("Copying portion of file")
-            # try:
-            #     # Copy/paste to text area
-            #     pyperclip.copy(text)
-            #     self.input_lang_from.write((Keys.CONTROL, "v"))
-            # except:
-            #     # Copies letter to letter if copy/paste fail
             self.input_lang_from.write((text))
 
-            logging.info("Waiting for traslation to complete")
+            logging.info("Waiting for translation to complete")
             for _ in range(60):  # Maximun number of iterations 60 seconds
-                traslation = self.input_lang_to.value
+                translation = self.input_lang_to.value
                 if (
-                    len(traslation) != 0
-                    and len(text.splitlines()) == len(traslation.splitlines())
-                    and "[...]" not in traslation
+                    len(translation) != 0
+                    and len(text.splitlines()) == len(translation.splitlines())
+                    and "[...]" not in translation
                 ):
                     break
                 time.sleep(1)
@@ -96,10 +86,16 @@ class Translator:
                     Make sure your SRT file does not contain the characters '[...]'"""
                 )
 
-            logging.info("Updating portion with traslation")
-            traslation = self.input_lang_to.value.splitlines()
+            if text == translation:
+                raise Exception(
+                    """No translation occurred.\n
+                    Make sure your SRT file does not contain HTML tags and/or HTML elements'"""
+                )
+
+            logging.info("Updating portion with translation")
+            translation = translation.splitlines()
 
             for i in range(len(portion)):
-                portion[i].content = traslation[i]
+                portion[i].content = translation[i]
 
         return subs
