@@ -1,10 +1,15 @@
 import os
 import glob
 import logging
+import random
 import geckodriver_autoinstaller
 
+from selenium import webdriver
+from selenium.webdriver.common.proxy import Proxy, ProxyType
+
 from .deepl import Translator
 from .srt_parser import wrap_line, save_srt
+from .utils import get_proxies
 
 # Check if the current version of geckodriver exists
 geckodriver_autoinstaller.install()
@@ -66,8 +71,36 @@ OUTPUT_LANG = {
 }
 
 
-def translate(filepath, lang_from, lang_to, wrap_limit, delete_old):
-    translator = Translator()
+def translate(
+    filepath,
+    lang_from,
+    lang_to,
+    wrap_limit=50,
+    delete_old=False,
+    driver=None,
+):
+
+    if driver is None:
+        proxies = get_proxies()
+        if len(proxies) == 0:
+            proxies = get_proxies(https=False)
+
+        my_proxy = random.choice(proxies)
+
+        proxy = Proxy(
+            {
+                "proxyType": ProxyType.MANUAL,
+                "httpProxy": my_proxy,
+                "ftpProxy": my_proxy,
+                "sslProxy": my_proxy,
+                "noProxy": "",  # set this value as desired
+            }
+        )
+
+        driver = webdriver.Firefox(proxy=proxy)
+        driver.maximize_window()
+
+    translator = Translator(driver)
 
     lang_from = {
         "lang": lang_from,
@@ -105,4 +138,4 @@ def translate(filepath, lang_from, lang_to, wrap_limit, delete_old):
         fname = os.path.splitext(fpath)[0]
         save_srt(fname, lang_to["lang"], subs)
 
-    translator.close()
\ No newline at end of file
+    translator.close()
